pub struct AgentContextHandle { /* private fields */ }Expand description
Shared compatibility handle for tools explicitly using the Legacy dependency profile.
Implementations
Sourceimpl AgentContextHandle
impl AgentContextHandle
Sourcepub fn new(context: AgentContext) -> Self
pub fn new(context: AgentContext) -> Self
Create a handle from a complete context snapshot.
Sourcepub fn snapshot(&self) -> AgentContext
pub fn snapshot(&self) -> AgentContext
Return the latest context snapshot held by this handle.
Sourcepub fn replace(&self, context: AgentContext)
pub fn replace(&self, context: AgentContext)
Replace the context snapshot held by this handle.
Sourcepub fn update(&self, update: impl FnOnce(&mut AgentContext))
pub fn update(&self, update: impl FnOnce(&mut AgentContext))
Mutate the context snapshot held by this handle.