pub struct ContextMutationHandles { /* private fields */ }Expand description
Runtime-owned collection of isolated context mutation cells for one tool call.
Implementations
Sourceimpl ContextMutationHandles
impl ContextMutationHandles
Sourcepub fn from_context(context: &AgentContext) -> Self
pub fn from_context(context: &AgentContext) -> Self
Capture only the domains that narrow handles can mutate.
Sourcepub fn insert_grants(
&self,
dependencies: &mut DependencyStore,
requested: &BTreeSet<String>,
)
pub fn insert_grants( &self, dependencies: &mut DependencyStore, requested: &BTreeSet<String>, )
Insert runtime-recognized capability handles into a dependency store.
Sourcepub fn apply_to(
&self,
context: &mut AgentContext,
authorized: &BTreeSet<String>,
)
pub fn apply_to( &self, context: &mut AgentContext, authorized: &BTreeSet<String>, )
Apply only explicitly authorized mutation domains back to the runtime context.