MessageBus

Struct MessageBus 

pub struct MessageBus { /* private fields */ }
Subscriber/cursor message bus with idempotent send and consume.

Implementations

Source

impl MessageBus

pub const fn new() -> Self

Create an empty message bus.

pub const fn with_maxlen(maxlen: usize) -> Self

Create an empty message bus with a bounded retention length.

pub fn subscribe(&mut self, agent_id: impl Into<String>)

Register a subscriber. New subscribers start at the current tail.

pub fn unsubscribe(&mut self, agent_id: &str)

Remove a subscriber and its cursor state.

pub fn is_subscribed(&self, agent_id: &str) -> bool

Return whether the given agent currently has a subscriber cursor.

pub fn send(&mut self, message: BusMessage) -> BusMessage

Send a message idempotently.

pub fn consume(&mut self, agent_id: impl Into<String>) -> Vec<BusMessage>

Consume unread messages for a subscriber.

pub fn consume_matching( &mut self, agent_id: impl Into<String>, predicate: impl Fn(&BusMessage) -> bool, ) -> Vec<BusMessage>

Consume unread messages matching a predicate while preserving other pending messages.

pub fn peek(&self, agent_id: &str) -> Vec<BusMessage>

Return unread messages without advancing the cursor.

pub fn mark_consumed( &mut self, agent_id: impl Into<String>, message_ids: &BTreeSet<String>, ) -> usize

Mark specific unread messages as consumed for a subscriber.

Returns the number of currently unread messages that were marked consumed.

pub fn has_pending(&self, agent_id: &str) -> bool

Return whether there are pending messages for one subscriber.

pub fn has_topic(&self, topic: &str) -> bool

Return whether any queued message has the provided topic.

pub fn clear(&mut self)

Clear all messages and subscriber state.

pub const fn len(&self) -> usize

Return number of retained messages.

pub fn subscriber_count(&self) -> usize

Return number of subscribers.

pub const fn is_empty(&self) -> bool

Return whether the bus has no messages.

pub fn messages(&self) -> &[BusMessage]

Return retained messages.