pub struct Task {
pub id: String,
pub subject: String,
pub description: String,
pub status: TaskStatus,
pub active_form: Option<String>,
pub owner: Option<String>,
pub blocked_by: Vec<String>,
pub blocks: Vec<String>,
pub metadata: Metadata,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Expand description
Agent-managed task record used by task tools and display snapshots.
Fields
id: StringTask identifier.
subject: StringTask title in imperative form.
description: StringDetailed task description.
status: TaskStatusCurrent task status: pending, in_progress, or completed.
active_form: Option<String>Present-progress label shown while in progress.
owner: Option<String>Optional task owner.
blocked_by: Vec<String>Task ids this task is blocked by.
blocks: Vec<String>Task ids this task blocks.
metadata: MetadataAdditional task metadata.
created_at: DateTime<Utc>Task creation timestamp.
updated_at: DateTime<Utc>Last update timestamp.
Implementations
Sourceimpl Task
impl Task
Sourcepub fn new(
id: impl Into<String>,
subject: impl Into<String>,
description: impl Into<String>,
) -> Self
pub fn new( id: impl Into<String>, subject: impl Into<String>, description: impl Into<String>, ) -> Self
Create a pending task.
Sourcepub const fn is_blocked(&self) -> bool
pub const fn is_blocked(&self) -> bool
Return whether task is blocked by any incomplete tasks.
Sourcepub const fn status_str(&self) -> &str
pub const fn status_str(&self) -> &str
Return status as a string.
Sourcepub fn set_status(&mut self, status: TaskStatus)
pub fn set_status(&mut self, status: TaskStatus)
Set status from a parsed status enum.