pub struct TaskContextHandle { /* private fields */ }Expand description
Capability-specific mutable handle for task-manager state.
Implementations
Sourceimpl TaskContextHandle
impl TaskContextHandle
Sourcepub fn from_context(context: &AgentContext) -> Self
pub fn from_context(context: &AgentContext) -> Self
Create a narrow task handle from current context values.
Sourcepub fn update<R>(
&self,
update: impl FnOnce(&mut TaskManager) -> R,
) -> (R, Vec<Task>)
pub fn update<R>( &self, update: impl FnOnce(&mut TaskManager) -> R, ) -> (R, Vec<Task>)
Mutate only the task manager and return its latest snapshot.
Sourcepub fn apply_to(&self, context: &mut AgentContext)
pub fn apply_to(&self, context: &mut AgentContext)
Apply the isolated task state and publish its durable snapshot to a context.